@@ -8,6 +8,7 @@ Usage::
     from mypy_boto3_workmail import (
         Client,
         ListAliasesPaginator,
+        ListAvailabilityConfigurationsPaginator,
         ListGroupMembersPaginator,
         ListGroupsPaginator,
         ListMailboxPermissionsPaginator,
@@ -22,6 +23,7 @@ Usage::
     client: WorkMailClient = session.client("workmail")
 
     list_aliases_paginator: ListAliasesPaginator = client.get_paginator("list_aliases")
+    list_availability_configurations_paginator: ListAvailabilityConfigurationsPaginator = client.get_paginator("list_availability_configurations")
     list_group_members_paginator: ListGroupMembersPaginator = client.get_paginator("list_group_members")
     list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
     list_mailbox_permissions_paginator: ListMailboxPermissionsPaginator = client.get_paginator("list_mailbox_permissions")
@@ -34,6 +36,7 @@ Usage::
 from .client import WorkMailClient
 from .paginator import (
     ListAliasesPaginator,
+    ListAvailabilityConfigurationsPaginator,
     ListGroupMembersPaginator,
     ListGroupsPaginator,
     ListMailboxPermissionsPaginator,
@@ -49,6 +52,7 @@ Client = WorkMailClient
 __all__ = (
     "Client",
     "ListAliasesPaginator",
+    "ListAvailabilityConfigurationsPaginator",
     "ListGroupMembersPaginator",
     "ListGroupsPaginator",
     "ListMailboxPermissionsPaginator",
