@@ -20,12 +20,14 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AccessControlRuleEffectType,
+    ImpersonationRoleTypeType,
     MobileDeviceAccessRuleEffectType,
     PermissionTypeType,
     ResourceTypeType,
 )
 from .paginator import (
     ListAliasesPaginator,
+    ListAvailabilityConfigurationsPaginator,
     ListGroupMembersPaginator,
     ListGroupsPaginator,
     ListMailboxPermissionsPaginator,
@@ -35,8 +37,10 @@ from .paginator import (
     ListUsersPaginator,
 )
 from .type_defs import (
+    AssumeImpersonationRoleResponseTypeDef,
     BookingOptionsTypeDef,
     CreateGroupResponseTypeDef,
+    CreateImpersonationRoleResponseTypeDef,
     CreateMobileDeviceAccessRuleResponseTypeDef,
     CreateOrganizationResponseTypeDef,
     CreateResourceResponseTypeDef,
@@ -50,17 +54,24 @@ from .type_defs import (
     DescribeResourceResponseTypeDef,
     DescribeUserResponseTypeDef,
     DomainTypeDef,
+    EwsAvailabilityProviderTypeDef,
     FolderConfigurationTypeDef,
     GetAccessControlEffectResponseTypeDef,
     GetDefaultRetentionPolicyResponseTypeDef,
+    GetImpersonationRoleEffectResponseTypeDef,
+    GetImpersonationRoleResponseTypeDef,
     GetMailboxDetailsResponseTypeDef,
     GetMailDomainResponseTypeDef,
     GetMobileDeviceAccessEffectResponseTypeDef,
     GetMobileDeviceAccessOverrideResponseTypeDef,
+    ImpersonationRuleTypeDef,
+    LambdaAvailabilityProviderTypeDef,
     ListAccessControlRulesResponseTypeDef,
     ListAliasesResponseTypeDef,
+    ListAvailabilityConfigurationsResponseTypeDef,
     ListGroupMembersResponseTypeDef,
     ListGroupsResponseTypeDef,
+    ListImpersonationRolesResponseTypeDef,
     ListMailboxExportJobsResponseTypeDef,
     ListMailboxPermissionsResponseTypeDef,
     ListMailDomainsResponseTypeDef,
@@ -73,6 +84,7 @@ from .type_defs import (
     ListUsersResponseTypeDef,
     StartMailboxExportJobResponseTypeDef,
     TagTypeDef,
+    TestAvailabilityConfigurationResponseTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -155,6 +167,16 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#associate_member_to_group)
         """
 
+    def assume_impersonation_role(
+        self, *, OrganizationId: str, ImpersonationRoleId: str
+    ) -> AssumeImpersonationRoleResponseTypeDef:
+        """
+        Assumes an impersonation role for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.assume_impersonation_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#assume_impersonation_role)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -173,23 +195,65 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#cancel_mailbox_export_job)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#close)
+        """
+
     def create_alias(self, *, OrganizationId: str, EntityId: str, Alias: str) -> Dict[str, Any]:
         """
-        Adds an alias to the set of a given member (user or group) of Amazon WorkMail.
+        Adds an alias to the set of a given member (user or group) of WorkMail.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_alias)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_alias)
         """
 
+    def create_availability_configuration(
+        self,
+        *,
+        OrganizationId: str,
+        DomainName: str,
+        ClientToken: str = ...,
+        EwsProvider: EwsAvailabilityProviderTypeDef = ...,
+        LambdaProvider: LambdaAvailabilityProviderTypeDef = ...
+    ) -> Dict[str, Any]:
+        """
+        Creates an `AvailabilityConfiguration` for the given WorkMail organization and
+        domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_availability_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_availability_configuration)
+        """
+
     def create_group(self, *, OrganizationId: str, Name: str) -> CreateGroupResponseTypeDef:
         """
-        Creates a group that can be used in Amazon WorkMail by calling the
-        RegisterToWorkMail operation.
+        Creates a group that can be used in WorkMail by calling the  RegisterToWorkMail
+        operation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_group)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_group)
         """
 
+    def create_impersonation_role(
+        self,
+        *,
+        OrganizationId: str,
+        Name: str,
+        Type: ImpersonationRoleTypeType,
+        Rules: Sequence[ImpersonationRuleTypeDef],
+        ClientToken: str = ...,
+        Description: str = ...
+    ) -> CreateImpersonationRoleResponseTypeDef:
+        """
+        Creates an impersonation role for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_impersonation_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_impersonation_role)
+        """
+
     def create_mobile_device_access_rule(
         self,
         *,
@@ -208,8 +272,7 @@ class WorkMailClient(BaseClient):
         NotDeviceUserAgents: Sequence[str] = ...
     ) -> CreateMobileDeviceAccessRuleResponseTypeDef:
         """
-        Creates a new mobile device access rule for the specified Amazon WorkMail
-        organization.
+        Creates a new mobile device access rule for the specified WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_mobile_device_access_rule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_mobile_device_access_rule)
@@ -226,7 +289,7 @@ class WorkMailClient(BaseClient):
         EnableInteroperability: bool = ...
     ) -> CreateOrganizationResponseTypeDef:
         """
-        Creates a new Amazon WorkMail organization.
+        Creates a new WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_organization)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_organization)
@@ -236,7 +299,7 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, Name: str, Type: ResourceTypeType
     ) -> CreateResourceResponseTypeDef:
         """
-        Creates a new Amazon WorkMail resource.
+        Creates a new WorkMail resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_resource)
@@ -246,8 +309,8 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, Name: str, DisplayName: str, Password: str
     ) -> CreateUserResponseTypeDef:
         """
-        Creates a user who can be used in Amazon WorkMail by calling the
-        RegisterToWorkMail operation.
+        Creates a user who can be used in WorkMail by calling the  RegisterToWorkMail
+        operation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.create_user)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#create_user)
@@ -269,6 +332,17 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_alias)
         """
 
+    def delete_availability_configuration(
+        self, *, OrganizationId: str, DomainName: str
+    ) -> Dict[str, Any]:
+        """
+        Deletes the `AvailabilityConfiguration` for the given WorkMail organization and
+        domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_availability_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_availability_configuration)
+        """
+
     def delete_email_monitoring_configuration(self, *, OrganizationId: str) -> Dict[str, Any]:
         """
         Deletes the email monitoring configuration for a specified organization.
@@ -279,12 +353,22 @@ class WorkMailClient(BaseClient):
 
     def delete_group(self, *, OrganizationId: str, GroupId: str) -> Dict[str, Any]:
         """
-        Deletes a group from Amazon WorkMail.
+        Deletes a group from WorkMail.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_group)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_group)
         """
 
+    def delete_impersonation_role(
+        self, *, OrganizationId: str, ImpersonationRoleId: str
+    ) -> Dict[str, Any]:
+        """
+        Deletes an impersonation role for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_impersonation_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_impersonation_role)
+        """
+
     def delete_mailbox_permissions(
         self, *, OrganizationId: str, EntityId: str, GranteeId: str
     ) -> Dict[str, Any]:
@@ -310,8 +394,7 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, MobileDeviceAccessRuleId: str
     ) -> Dict[str, Any]:
         """
-        Deletes a mobile device access rule for the specified Amazon WorkMail
-        organization.
+        Deletes a mobile device access rule for the specified WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_mobile_device_access_rule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_mobile_device_access_rule)
@@ -321,8 +404,8 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, DeleteDirectory: bool, ClientToken: str = ...
     ) -> DeleteOrganizationResponseTypeDef:
         """
-        Deletes an Amazon WorkMail organization and all underlying AWS resources managed
-        by Amazon WorkMail as part of the organization.
+        Deletes an WorkMail organization and all underlying AWS resources managed by
+        WorkMail as part of the organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_organization)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_organization)
@@ -346,7 +429,7 @@ class WorkMailClient(BaseClient):
 
     def delete_user(self, *, OrganizationId: str, UserId: str) -> Dict[str, Any]:
         """
-        Deletes a user from Amazon WorkMail and all subsequent systems.
+        Deletes a user from WorkMail and all subsequent systems.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.delete_user)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#delete_user)
@@ -354,7 +437,7 @@ class WorkMailClient(BaseClient):
 
     def deregister_from_work_mail(self, *, OrganizationId: str, EntityId: str) -> Dict[str, Any]:
         """
-        Mark a user, group, or resource as no longer used in Amazon WorkMail.
+        Mark a user, group, or resource as no longer used in WorkMail.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.deregister_from_work_mail)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#deregister_from_work_mail)
@@ -362,8 +445,8 @@ class WorkMailClient(BaseClient):
 
     def deregister_mail_domain(self, *, OrganizationId: str, DomainName: str) -> Dict[str, Any]:
         """
-        Removes a domain from Amazon WorkMail, stops email routing to WorkMail, and
-        removes the authorization allowing WorkMail use.
+        Removes a domain from WorkMail, stops email routing to WorkMail, and removes the
+        authorization allowing WorkMail use.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.deregister_mail_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#deregister_mail_domain)
@@ -470,11 +553,18 @@ class WorkMailClient(BaseClient):
         """
 
     def get_access_control_effect(
-        self, *, OrganizationId: str, IpAddress: str, Action: str, UserId: str
+        self,
+        *,
+        OrganizationId: str,
+        IpAddress: str,
+        Action: str,
+        UserId: str = ...,
+        ImpersonationRoleId: str = ...
     ) -> GetAccessControlEffectResponseTypeDef:
         """
         Gets the effects of an organization's access control rules as they apply to a
-        specified IPv4 address, access protocol action, or user ID.
+        specified IPv4 address, access protocol action, and user ID or impersonation
+        role ID.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.get_access_control_effect)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_access_control_effect)
@@ -490,6 +580,26 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_default_retention_policy)
         """
 
+    def get_impersonation_role(
+        self, *, OrganizationId: str, ImpersonationRoleId: str
+    ) -> GetImpersonationRoleResponseTypeDef:
+        """
+        Gets the impersonation role details for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.get_impersonation_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_impersonation_role)
+        """
+
+    def get_impersonation_role_effect(
+        self, *, OrganizationId: str, ImpersonationRoleId: str, TargetUser: str
+    ) -> GetImpersonationRoleEffectResponseTypeDef:
+        """
+        Tests whether the given impersonation role can impersonate a target user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.get_impersonation_role_effect)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_impersonation_role_effect)
+        """
+
     def get_mail_domain(
         self, *, OrganizationId: str, DomainName: str
     ) -> GetMailDomainResponseTypeDef:
@@ -559,6 +669,16 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_aliases)
         """
 
+    def list_availability_configurations(
+        self, *, OrganizationId: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListAvailabilityConfigurationsResponseTypeDef:
+        """
+        List all the `AvailabilityConfiguration` 's for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.list_availability_configurations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_availability_configurations)
+        """
+
     def list_group_members(
         self, *, OrganizationId: str, GroupId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListGroupMembersResponseTypeDef:
@@ -579,11 +699,21 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_groups)
         """
 
+    def list_impersonation_roles(
+        self, *, OrganizationId: str, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListImpersonationRolesResponseTypeDef:
+        """
+        Lists all the impersonation roles for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.list_impersonation_roles)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_impersonation_roles)
+        """
+
     def list_mail_domains(
         self, *, OrganizationId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListMailDomainsResponseTypeDef:
         """
-        Lists the mail domains in a given Amazon WorkMail organization.
+        Lists the mail domains in a given WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.list_mail_domains)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_mail_domains)
@@ -632,8 +762,7 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str
     ) -> ListMobileDeviceAccessRulesResponseTypeDef:
         """
-        Lists the mobile device access rules for the specified Amazon WorkMail
-        organization.
+        Lists the mobile device access rules for the specified WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.list_mobile_device_access_rules)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_mobile_device_access_rules)
@@ -671,7 +800,7 @@ class WorkMailClient(BaseClient):
 
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        Lists the tags applied to an Amazon WorkMail organization resource.
+        Lists the tags applied to an WorkMail organization resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#list_tags_for_resource)
@@ -699,7 +828,9 @@ class WorkMailClient(BaseClient):
         Actions: Sequence[str] = ...,
         NotActions: Sequence[str] = ...,
         UserIds: Sequence[str] = ...,
-        NotUserIds: Sequence[str] = ...
+        NotUserIds: Sequence[str] = ...,
+        ImpersonationRoleIds: Sequence[str] = ...,
+        NotImpersonationRoleIds: Sequence[str] = ...
     ) -> Dict[str, Any]:
         """
         Adds a new access control rule for the specified organization.
@@ -779,7 +910,7 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, DomainName: str, ClientToken: str = ...
     ) -> Dict[str, Any]:
         """
-        Registers a new domain in Amazon WorkMail and SES, and configures it for use by
+        Registers a new domain in WorkMail and SES, and configures it for use by
         WorkMail.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.register_mail_domain)
@@ -790,8 +921,8 @@ class WorkMailClient(BaseClient):
         self, *, OrganizationId: str, EntityId: str, Email: str
     ) -> Dict[str, Any]:
         """
-        Registers an existing and disabled user, group, or resource for Amazon WorkMail
-        use by associating a mailbox and calendaring capabilities.
+        Registers an existing and disabled user, group, or resource for WorkMail use by
+        associating a mailbox and calendaring capabilities.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.register_to_work_mail)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#register_to_work_mail)
@@ -828,22 +959,51 @@ class WorkMailClient(BaseClient):
 
     def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
-        Applies the specified tags to the specified Amazon WorkMail organization
-        resource.
+        Applies the specified tags to the specified WorkMailorganization resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#tag_resource)
         """
 
+    def test_availability_configuration(
+        self,
+        *,
+        OrganizationId: str,
+        DomainName: str = ...,
+        EwsProvider: EwsAvailabilityProviderTypeDef = ...,
+        LambdaProvider: LambdaAvailabilityProviderTypeDef = ...
+    ) -> TestAvailabilityConfigurationResponseTypeDef:
+        """
+        Performs a test on an availability provider to ensure that access is allowed.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.test_availability_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#test_availability_configuration)
+        """
+
     def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
-        Untags the specified tags from the specified Amazon WorkMail organization
-        resource.
+        Untags the specified tags from the specified WorkMail organization resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#untag_resource)
         """
 
+    def update_availability_configuration(
+        self,
+        *,
+        OrganizationId: str,
+        DomainName: str,
+        EwsProvider: EwsAvailabilityProviderTypeDef = ...,
+        LambdaProvider: LambdaAvailabilityProviderTypeDef = ...
+    ) -> Dict[str, Any]:
+        """
+        Updates an existing `AvailabilityConfiguration` for the given WorkMail
+        organization and domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.update_availability_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#update_availability_configuration)
+        """
+
     def update_default_mail_domain(self, *, OrganizationId: str, DomainName: str) -> Dict[str, Any]:
         """
         Updates the default mail domain for an organization.
@@ -852,6 +1012,23 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#update_default_mail_domain)
         """
 
+    def update_impersonation_role(
+        self,
+        *,
+        OrganizationId: str,
+        ImpersonationRoleId: str,
+        Name: str,
+        Type: ImpersonationRoleTypeType,
+        Rules: Sequence[ImpersonationRuleTypeDef],
+        Description: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Updates an impersonation role for the given WorkMail organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.update_impersonation_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#update_impersonation_role)
+        """
+
     def update_mailbox_quota(
         self, *, OrganizationId: str, UserId: str, MailboxQuota: int
     ) -> Dict[str, Any]:
@@ -880,8 +1057,7 @@ class WorkMailClient(BaseClient):
         NotDeviceUserAgents: Sequence[str] = ...
     ) -> Dict[str, Any]:
         """
-        Updates a mobile device access rule for the specified Amazon WorkMail
-        organization.
+        Updates a mobile device access rule for the specified WorkMail organization.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.update_mobile_device_access_rule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#update_mobile_device_access_rule)
@@ -919,6 +1095,15 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_availability_configurations"]
+    ) -> ListAvailabilityConfigurationsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_group_members"]
