@@ -21,10 +21,14 @@ else:
 
 __all__ = (
     "AccessControlRuleEffectType",
+    "AccessEffectType",
+    "AvailabilityProviderTypeType",
     "DnsRecordVerificationStatusType",
     "EntityStateType",
     "FolderNameType",
+    "ImpersonationRoleTypeType",
     "ListAliasesPaginatorName",
+    "ListAvailabilityConfigurationsPaginatorName",
     "ListGroupMembersPaginatorName",
     "ListGroupsPaginatorName",
     "ListMailboxPermissionsPaginatorName",
@@ -48,10 +52,14 @@ __all__ = (
 
 
 AccessControlRuleEffectType = Literal["ALLOW", "DENY"]
+AccessEffectType = Literal["ALLOW", "DENY"]
+AvailabilityProviderTypeType = Literal["EWS", "LAMBDA"]
 DnsRecordVerificationStatusType = Literal["FAILED", "PENDING", "VERIFIED"]
 EntityStateType = Literal["DELETED", "DISABLED", "ENABLED"]
 FolderNameType = Literal["DELETED_ITEMS", "DRAFTS", "INBOX", "JUNK_EMAIL", "SENT_ITEMS"]
+ImpersonationRoleTypeType = Literal["FULL_ACCESS", "READ_ONLY"]
 ListAliasesPaginatorName = Literal["list_aliases"]
+ListAvailabilityConfigurationsPaginatorName = Literal["list_availability_configurations"]
 ListGroupMembersPaginatorName = Literal["list_group_members"]
 ListGroupsPaginatorName = Literal["list_groups"]
 ListMailboxPermissionsPaginatorName = Literal["list_mailbox_permissions"]
@@ -97,6 +105,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -137,7 +146,10 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -215,6 +227,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -241,12 +254,14 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -268,6 +283,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -293,6 +309,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -303,11 +320,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -353,6 +372,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -389,6 +409,7 @@ ResourceServiceName = Literal[
 ]
 PaginatorName = Literal[
     "list_aliases",
+    "list_availability_configurations",
     "list_group_members",
     "list_groups",
     "list_mailbox_permissions",
