@@ -11,6 +11,7 @@ Usage::
     from mypy_boto3_workmail.client import WorkMailClient
     from mypy_boto3_workmail.paginator import (
         ListAliasesPaginator,
+        ListAvailabilityConfigurationsPaginator,
         ListGroupMembersPaginator,
         ListGroupsPaginator,
         ListMailboxPermissionsPaginator,
@@ -24,6 +25,7 @@ Usage::
     client: WorkMailClient = session.client("workmail")
 
     list_aliases_paginator: ListAliasesPaginator = client.get_paginator("list_aliases")
+    list_availability_configurations_paginator: ListAvailabilityConfigurationsPaginator = client.get_paginator("list_availability_configurations")
     list_group_members_paginator: ListGroupMembersPaginator = client.get_paginator("list_group_members")
     list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
     list_mailbox_permissions_paginator: ListMailboxPermissionsPaginator = client.get_paginator("list_mailbox_permissions")
@@ -35,11 +37,11 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListAliasesResponseTypeDef,
+    ListAvailabilityConfigurationsResponseTypeDef,
     ListGroupMembersResponseTypeDef,
     ListGroupsResponseTypeDef,
     ListMailboxPermissionsResponseTypeDef,
@@ -52,6 +54,7 @@ from .type_defs import (
 
 __all__ = (
     "ListAliasesPaginator",
+    "ListAvailabilityConfigurationsPaginator",
     "ListGroupMembersPaginator",
     "ListGroupsPaginator",
     "ListMailboxPermissionsPaginator",
@@ -72,7 +75,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAliasesPaginator(Boto3Paginator):
+class ListAliasesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListAliases)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listaliasespaginator)
@@ -87,7 +90,22 @@ class ListAliasesPaginator(Boto3Paginator):
         """
 
 
-class ListGroupMembersPaginator(Boto3Paginator):
+class ListAvailabilityConfigurationsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListAvailabilityConfigurations)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listavailabilityconfigurationspaginator)
+    """
+
+    def paginate(
+        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAvailabilityConfigurationsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListAvailabilityConfigurations.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listavailabilityconfigurationspaginator)
+        """
+
+
+class ListGroupMembersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListGroupMembers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listgroupmemberspaginator)
@@ -102,7 +120,7 @@ class ListGroupMembersPaginator(Boto3Paginator):
         """
 
 
-class ListGroupsPaginator(Boto3Paginator):
+class ListGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listgroupspaginator)
@@ -117,7 +135,7 @@ class ListGroupsPaginator(Boto3Paginator):
         """
 
 
-class ListMailboxPermissionsPaginator(Boto3Paginator):
+class ListMailboxPermissionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListMailboxPermissions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listmailboxpermissionspaginator)
@@ -132,7 +150,7 @@ class ListMailboxPermissionsPaginator(Boto3Paginator):
         """
 
 
-class ListOrganizationsPaginator(Boto3Paginator):
+class ListOrganizationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListOrganizations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listorganizationspaginator)
@@ -147,7 +165,7 @@ class ListOrganizationsPaginator(Boto3Paginator):
         """
 
 
-class ListResourceDelegatesPaginator(Boto3Paginator):
+class ListResourceDelegatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListResourceDelegates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listresourcedelegatespaginator)
@@ -166,7 +184,7 @@ class ListResourceDelegatesPaginator(Boto3Paginator):
         """
 
 
-class ListResourcesPaginator(Boto3Paginator):
+class ListResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listresourcespaginator)
@@ -181,7 +199,7 @@ class ListResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListUsersPaginator(Boto3Paginator):
+class ListUsersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListUsers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/paginators/#listuserspaginator)
