@@ -17,9 +17,12 @@ from typing import Dict, List, Sequence
 
 from .literals import (
     AccessControlRuleEffectType,
+    AccessEffectType,
+    AvailabilityProviderTypeType,
     DnsRecordVerificationStatusType,
     EntityStateType,
     FolderNameType,
+    ImpersonationRoleTypeType,
     MailboxExportJobStateType,
     MemberTypeType,
     MobileDeviceAccessRuleEffectType,
@@ -39,11 +42,16 @@ __all__ = (
     "AccessControlRuleTypeDef",
     "AssociateDelegateToResourceRequestRequestTypeDef",
     "AssociateMemberToGroupRequestRequestTypeDef",
+    "AssumeImpersonationRoleRequestRequestTypeDef",
+    "ResponseMetadataTypeDef",
+    "LambdaAvailabilityProviderTypeDef",
+    "RedactedEwsAvailabilityProviderTypeDef",
     "BookingOptionsTypeDef",
     "CancelMailboxExportJobRequestRequestTypeDef",
     "CreateAliasRequestRequestTypeDef",
+    "EwsAvailabilityProviderTypeDef",
     "CreateGroupRequestRequestTypeDef",
-    "ResponseMetadataTypeDef",
+    "ImpersonationRuleTypeDef",
     "CreateMobileDeviceAccessRuleRequestRequestTypeDef",
     "DomainTypeDef",
     "CreateResourceRequestRequestTypeDef",
@@ -51,8 +59,10 @@ __all__ = (
     "DelegateTypeDef",
     "DeleteAccessControlRuleRequestRequestTypeDef",
     "DeleteAliasRequestRequestTypeDef",
+    "DeleteAvailabilityConfigurationRequestRequestTypeDef",
     "DeleteEmailMonitoringConfigurationRequestRequestTypeDef",
     "DeleteGroupRequestRequestTypeDef",
+    "DeleteImpersonationRoleRequestRequestTypeDef",
     "DeleteMailboxPermissionsRequestRequestTypeDef",
     "DeleteMobileDeviceAccessOverrideRequestRequestTypeDef",
     "DeleteMobileDeviceAccessRuleRequestRequestTypeDef",
@@ -75,18 +85,24 @@ __all__ = (
     "FolderConfigurationTypeDef",
     "GetAccessControlEffectRequestRequestTypeDef",
     "GetDefaultRetentionPolicyRequestRequestTypeDef",
+    "GetImpersonationRoleEffectRequestRequestTypeDef",
+    "ImpersonationMatchedRuleTypeDef",
+    "GetImpersonationRoleRequestRequestTypeDef",
     "GetMailDomainRequestRequestTypeDef",
     "GetMailboxDetailsRequestRequestTypeDef",
     "GetMobileDeviceAccessEffectRequestRequestTypeDef",
     "MobileDeviceAccessMatchedRuleTypeDef",
     "GetMobileDeviceAccessOverrideRequestRequestTypeDef",
     "GroupTypeDef",
+    "ImpersonationRoleTypeDef",
     "ListAccessControlRulesRequestRequestTypeDef",
     "PaginatorConfigTypeDef",
     "ListAliasesRequestRequestTypeDef",
+    "ListAvailabilityConfigurationsRequestRequestTypeDef",
     "ListGroupMembersRequestRequestTypeDef",
     "MemberTypeDef",
     "ListGroupsRequestRequestTypeDef",
+    "ListImpersonationRolesRequestRequestTypeDef",
     "ListMailDomainsRequestRequestTypeDef",
     "MailDomainSummaryTypeDef",
     "ListMailboxExportJobsRequestRequestTypeDef",
@@ -120,8 +136,9 @@ __all__ = (
     "UpdateMailboxQuotaRequestRequestTypeDef",
     "UpdateMobileDeviceAccessRuleRequestRequestTypeDef",
     "UpdatePrimaryEmailAddressRequestRequestTypeDef",
-    "UpdateResourceRequestRequestTypeDef",
+    "AssumeImpersonationRoleResponseTypeDef",
     "CreateGroupResponseTypeDef",
+    "CreateImpersonationRoleResponseTypeDef",
     "CreateMobileDeviceAccessRuleResponseTypeDef",
     "CreateOrganizationResponseTypeDef",
     "CreateResourceResponseTypeDef",
@@ -132,7 +149,6 @@ __all__ = (
     "DescribeInboundDmarcSettingsResponseTypeDef",
     "DescribeMailboxExportJobResponseTypeDef",
     "DescribeOrganizationResponseTypeDef",
-    "DescribeResourceResponseTypeDef",
     "DescribeUserResponseTypeDef",
     "GetAccessControlEffectResponseTypeDef",
     "GetMailboxDetailsResponseTypeDef",
@@ -140,14 +156,27 @@ __all__ = (
     "ListAccessControlRulesResponseTypeDef",
     "ListAliasesResponseTypeDef",
     "StartMailboxExportJobResponseTypeDef",
+    "TestAvailabilityConfigurationResponseTypeDef",
+    "AvailabilityConfigurationTypeDef",
+    "DescribeResourceResponseTypeDef",
+    "UpdateResourceRequestRequestTypeDef",
+    "CreateAvailabilityConfigurationRequestRequestTypeDef",
+    "TestAvailabilityConfigurationRequestRequestTypeDef",
+    "UpdateAvailabilityConfigurationRequestRequestTypeDef",
+    "CreateImpersonationRoleRequestRequestTypeDef",
+    "GetImpersonationRoleResponseTypeDef",
+    "UpdateImpersonationRoleRequestRequestTypeDef",
     "CreateOrganizationRequestRequestTypeDef",
     "ListResourceDelegatesResponseTypeDef",
     "GetMailDomainResponseTypeDef",
     "GetDefaultRetentionPolicyResponseTypeDef",
     "PutRetentionPolicyRequestRequestTypeDef",
+    "GetImpersonationRoleEffectResponseTypeDef",
     "GetMobileDeviceAccessEffectResponseTypeDef",
     "ListGroupsResponseTypeDef",
+    "ListImpersonationRolesResponseTypeDef",
     "ListAliasesRequestListAliasesPaginateTypeDef",
+    "ListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef",
     "ListGroupMembersRequestListGroupMembersPaginateTypeDef",
     "ListGroupsRequestListGroupsPaginateTypeDef",
     "ListMailboxPermissionsRequestListMailboxPermissionsPaginateTypeDef",
@@ -166,6 +195,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "ListUsersResponseTypeDef",
+    "ListAvailabilityConfigurationsResponseTypeDef",
 )
 
 AccessControlRuleTypeDef = TypedDict(
@@ -182,6 +212,8 @@ AccessControlRuleTypeDef = TypedDict(
         "NotUserIds": List[str],
         "DateCreated": datetime,
         "DateModified": datetime,
+        "ImpersonationRoleIds": List[str],
+        "NotImpersonationRoleIds": List[str],
     },
     total=False,
 )
@@ -204,6 +236,41 @@ AssociateMemberToGroupRequestRequestTypeDef = TypedDict(
     },
 )
 
+AssumeImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "AssumeImpersonationRoleRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ImpersonationRoleId": str,
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
+LambdaAvailabilityProviderTypeDef = TypedDict(
+    "LambdaAvailabilityProviderTypeDef",
+    {
+        "LambdaArn": str,
+    },
+)
+
+RedactedEwsAvailabilityProviderTypeDef = TypedDict(
+    "RedactedEwsAvailabilityProviderTypeDef",
+    {
+        "EwsEndpoint": str,
+        "EwsUsername": str,
+    },
+    total=False,
+)
+
 BookingOptionsTypeDef = TypedDict(
     "BookingOptionsTypeDef",
     {
@@ -232,6 +299,15 @@ CreateAliasRequestRequestTypeDef = TypedDict(
     },
 )
 
+EwsAvailabilityProviderTypeDef = TypedDict(
+    "EwsAvailabilityProviderTypeDef",
+    {
+        "EwsEndpoint": str,
+        "EwsUsername": str,
+        "EwsPassword": str,
+    },
+)
+
 CreateGroupRequestRequestTypeDef = TypedDict(
     "CreateGroupRequestRequestTypeDef",
     {
@@ -240,16 +316,30 @@ CreateGroupRequestRequestTypeDef = TypedDict(
     },
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+_RequiredImpersonationRuleTypeDef = TypedDict(
+    "_RequiredImpersonationRuleTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ImpersonationRuleId": str,
+        "Effect": AccessEffectType,
     },
 )
+_OptionalImpersonationRuleTypeDef = TypedDict(
+    "_OptionalImpersonationRuleTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "TargetUsers": Sequence[str],
+        "NotTargetUsers": Sequence[str],
+    },
+    total=False,
+)
+
+
+class ImpersonationRuleTypeDef(
+    _RequiredImpersonationRuleTypeDef, _OptionalImpersonationRuleTypeDef
+):
+    pass
+
 
 _RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     "_RequiredCreateMobileDeviceAccessRuleRequestRequestTypeDef",
@@ -337,6 +427,14 @@ DeleteAliasRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "DeleteAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+
 DeleteEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
     "DeleteEmailMonitoringConfigurationRequestRequestTypeDef",
     {
@@ -352,6 +450,14 @@ DeleteGroupRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "DeleteImpersonationRoleRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ImpersonationRoleId": str,
+    },
+)
+
 DeleteMailboxPermissionsRequestRequestTypeDef = TypedDict(
     "DeleteMailboxPermissionsRequestRequestTypeDef",
     {
@@ -544,15 +650,30 @@ class FolderConfigurationTypeDef(
     pass
 
 
-GetAccessControlEffectRequestRequestTypeDef = TypedDict(
-    "GetAccessControlEffectRequestRequestTypeDef",
+_RequiredGetAccessControlEffectRequestRequestTypeDef = TypedDict(
+    "_RequiredGetAccessControlEffectRequestRequestTypeDef",
     {
         "OrganizationId": str,
         "IpAddress": str,
         "Action": str,
-        "UserId": str,
     },
 )
+_OptionalGetAccessControlEffectRequestRequestTypeDef = TypedDict(
+    "_OptionalGetAccessControlEffectRequestRequestTypeDef",
+    {
+        "UserId": str,
+        "ImpersonationRoleId": str,
+    },
+    total=False,
+)
+
+
+class GetAccessControlEffectRequestRequestTypeDef(
+    _RequiredGetAccessControlEffectRequestRequestTypeDef,
+    _OptionalGetAccessControlEffectRequestRequestTypeDef,
+):
+    pass
+
 
 GetDefaultRetentionPolicyRequestRequestTypeDef = TypedDict(
     "GetDefaultRetentionPolicyRequestRequestTypeDef",
@@ -561,6 +682,32 @@ GetDefaultRetentionPolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetImpersonationRoleEffectRequestRequestTypeDef = TypedDict(
+    "GetImpersonationRoleEffectRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ImpersonationRoleId": str,
+        "TargetUser": str,
+    },
+)
+
+ImpersonationMatchedRuleTypeDef = TypedDict(
+    "ImpersonationMatchedRuleTypeDef",
+    {
+        "ImpersonationRuleId": str,
+        "Name": str,
+    },
+    total=False,
+)
+
+GetImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "GetImpersonationRoleRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ImpersonationRoleId": str,
+    },
+)
+
 GetMailDomainRequestRequestTypeDef = TypedDict(
     "GetMailDomainRequestRequestTypeDef",
     {
@@ -633,6 +780,18 @@ GroupTypeDef = TypedDict(
     total=False,
 )
 
+ImpersonationRoleTypeDef = TypedDict(
+    "ImpersonationRoleTypeDef",
+    {
+        "ImpersonationRoleId": str,
+        "Name": str,
+        "Type": ImpersonationRoleTypeType,
+        "DateCreated": datetime,
+        "DateModified": datetime,
+    },
+    total=False,
+)
+
 ListAccessControlRulesRequestRequestTypeDef = TypedDict(
     "ListAccessControlRulesRequestRequestTypeDef",
     {
@@ -673,6 +832,29 @@ class ListAliasesRequestRequestTypeDef(
     pass
 
 
+_RequiredListAvailabilityConfigurationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAvailabilityConfigurationsRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalListAvailabilityConfigurationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAvailabilityConfigurationsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAvailabilityConfigurationsRequestRequestTypeDef(
+    _RequiredListAvailabilityConfigurationsRequestRequestTypeDef,
+    _OptionalListAvailabilityConfigurationsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredListGroupMembersRequestRequestTypeDef = TypedDict(
     "_RequiredListGroupMembersRequestRequestTypeDef",
     {
@@ -731,6 +913,29 @@ class ListGroupsRequestRequestTypeDef(
     pass
 
 
+_RequiredListImpersonationRolesRequestRequestTypeDef = TypedDict(
+    "_RequiredListImpersonationRolesRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalListImpersonationRolesRequestRequestTypeDef = TypedDict(
+    "_OptionalListImpersonationRolesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListImpersonationRolesRequestRequestTypeDef(
+    _RequiredListImpersonationRolesRequestRequestTypeDef,
+    _OptionalListImpersonationRolesRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredListMailDomainsRequestRequestTypeDef = TypedDict(
     "_RequiredListMailDomainsRequestRequestTypeDef",
     {
@@ -1051,6 +1256,8 @@ _OptionalPutAccessControlRuleRequestRequestTypeDef = TypedDict(
         "NotActions": Sequence[str],
         "UserIds": Sequence[str],
         "NotUserIds": Sequence[str],
+        "ImpersonationRoleIds": Sequence[str],
+        "NotImpersonationRoleIds": Sequence[str],
     },
     total=False,
 )
@@ -1251,28 +1458,14 @@ UpdatePrimaryEmailAddressRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateResourceRequestRequestTypeDef",
+AssumeImpersonationRoleResponseTypeDef = TypedDict(
+    "AssumeImpersonationRoleResponseTypeDef",
     {
-        "OrganizationId": str,
-        "ResourceId": str,
+        "Token": str,
+        "ExpiresIn": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-_OptionalUpdateResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateResourceRequestRequestTypeDef",
-    {
-        "Name": str,
-        "BookingOptions": BookingOptionsTypeDef,
-    },
-    total=False,
-)
-
-
-class UpdateResourceRequestRequestTypeDef(
-    _RequiredUpdateResourceRequestRequestTypeDef, _OptionalUpdateResourceRequestRequestTypeDef
-):
-    pass
-
 
 CreateGroupResponseTypeDef = TypedDict(
     "CreateGroupResponseTypeDef",
@@ -1282,6 +1475,14 @@ CreateGroupResponseTypeDef = TypedDict(
     },
 )
 
+CreateImpersonationRoleResponseTypeDef = TypedDict(
+    "CreateImpersonationRoleResponseTypeDef",
+    {
+        "ImpersonationRoleId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
     "CreateMobileDeviceAccessRuleResponseTypeDef",
     {
@@ -1388,21 +1589,6 @@ DescribeOrganizationResponseTypeDef = TypedDict(
     },
 )
 
-DescribeResourceResponseTypeDef = TypedDict(
-    "DescribeResourceResponseTypeDef",
-    {
-        "ResourceId": str,
-        "Email": str,
-        "Name": str,
-        "Type": ResourceTypeType,
-        "BookingOptions": BookingOptionsTypeDef,
-        "State": EntityStateType,
-        "EnabledDate": datetime,
-        "DisabledDate": datetime,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 DescribeUserResponseTypeDef = TypedDict(
     "DescribeUserResponseTypeDef",
     {
@@ -1474,6 +1660,205 @@ StartMailboxExportJobResponseTypeDef = TypedDict(
     },
 )
 
+TestAvailabilityConfigurationResponseTypeDef = TypedDict(
+    "TestAvailabilityConfigurationResponseTypeDef",
+    {
+        "TestPassed": bool,
+        "FailureReason": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AvailabilityConfigurationTypeDef = TypedDict(
+    "AvailabilityConfigurationTypeDef",
+    {
+        "DomainName": str,
+        "ProviderType": AvailabilityProviderTypeType,
+        "EwsProvider": RedactedEwsAvailabilityProviderTypeDef,
+        "LambdaProvider": LambdaAvailabilityProviderTypeDef,
+        "DateCreated": datetime,
+        "DateModified": datetime,
+    },
+    total=False,
+)
+
+DescribeResourceResponseTypeDef = TypedDict(
+    "DescribeResourceResponseTypeDef",
+    {
+        "ResourceId": str,
+        "Email": str,
+        "Name": str,
+        "Type": ResourceTypeType,
+        "BookingOptions": BookingOptionsTypeDef,
+        "State": EntityStateType,
+        "EnabledDate": datetime,
+        "DisabledDate": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredUpdateResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateResourceRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ResourceId": str,
+    },
+)
+_OptionalUpdateResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateResourceRequestRequestTypeDef",
+    {
+        "Name": str,
+        "BookingOptions": BookingOptionsTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateResourceRequestRequestTypeDef(
+    _RequiredUpdateResourceRequestRequestTypeDef, _OptionalUpdateResourceRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+_OptionalCreateAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "EwsProvider": EwsAvailabilityProviderTypeDef,
+        "LambdaProvider": LambdaAvailabilityProviderTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateAvailabilityConfigurationRequestRequestTypeDef(
+    _RequiredCreateAvailabilityConfigurationRequestRequestTypeDef,
+    _OptionalCreateAvailabilityConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredTestAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredTestAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalTestAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalTestAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "EwsProvider": EwsAvailabilityProviderTypeDef,
+        "LambdaProvider": LambdaAvailabilityProviderTypeDef,
+    },
+    total=False,
+)
+
+
+class TestAvailabilityConfigurationRequestRequestTypeDef(
+    _RequiredTestAvailabilityConfigurationRequestRequestTypeDef,
+    _OptionalTestAvailabilityConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+_OptionalUpdateAvailabilityConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAvailabilityConfigurationRequestRequestTypeDef",
+    {
+        "EwsProvider": EwsAvailabilityProviderTypeDef,
+        "LambdaProvider": LambdaAvailabilityProviderTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateAvailabilityConfigurationRequestRequestTypeDef(
+    _RequiredUpdateAvailabilityConfigurationRequestRequestTypeDef,
+    _OptionalUpdateAvailabilityConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateImpersonationRoleRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "Name": str,
+        "Type": ImpersonationRoleTypeType,
+        "Rules": Sequence[ImpersonationRuleTypeDef],
+    },
+)
+_OptionalCreateImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateImpersonationRoleRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class CreateImpersonationRoleRequestRequestTypeDef(
+    _RequiredCreateImpersonationRoleRequestRequestTypeDef,
+    _OptionalCreateImpersonationRoleRequestRequestTypeDef,
+):
+    pass
+
+
+GetImpersonationRoleResponseTypeDef = TypedDict(
+    "GetImpersonationRoleResponseTypeDef",
+    {
+        "ImpersonationRoleId": str,
+        "Name": str,
+        "Type": ImpersonationRoleTypeType,
+        "Description": str,
+        "Rules": List[ImpersonationRuleTypeDef],
+        "DateCreated": datetime,
+        "DateModified": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredUpdateImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateImpersonationRoleRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "ImpersonationRoleId": str,
+        "Name": str,
+        "Type": ImpersonationRoleTypeType,
+        "Rules": Sequence[ImpersonationRuleTypeDef],
+    },
+)
+_OptionalUpdateImpersonationRoleRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateImpersonationRoleRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateImpersonationRoleRequestRequestTypeDef(
+    _RequiredUpdateImpersonationRoleRequestRequestTypeDef,
+    _OptionalUpdateImpersonationRoleRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredCreateOrganizationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateOrganizationRequestRequestTypeDef",
     {
@@ -1557,6 +1942,16 @@ class PutRetentionPolicyRequestRequestTypeDef(
     pass
 
 
+GetImpersonationRoleEffectResponseTypeDef = TypedDict(
+    "GetImpersonationRoleEffectResponseTypeDef",
+    {
+        "Type": ImpersonationRoleTypeType,
+        "Effect": AccessEffectType,
+        "MatchedRules": List[ImpersonationMatchedRuleTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
     "GetMobileDeviceAccessEffectResponseTypeDef",
     {
@@ -1575,6 +1970,15 @@ ListGroupsResponseTypeDef = TypedDict(
     },
 )
 
+ListImpersonationRolesResponseTypeDef = TypedDict(
+    "ListImpersonationRolesResponseTypeDef",
+    {
+        "Roles": List[ImpersonationRoleTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredListAliasesRequestListAliasesPaginateTypeDef = TypedDict(
     "_RequiredListAliasesRequestListAliasesPaginateTypeDef",
     {
@@ -1598,6 +2002,28 @@ class ListAliasesRequestListAliasesPaginateTypeDef(
     pass
 
 
+_RequiredListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef = TypedDict(
+    "_RequiredListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef = TypedDict(
+    "_OptionalListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef(
+    _RequiredListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef,
+    _OptionalListAvailabilityConfigurationsRequestListAvailabilityConfigurationsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListGroupMembersRequestListGroupMembersPaginateTypeDef = TypedDict(
     "_RequiredListGroupMembersRequestListGroupMembersPaginateTypeDef",
     {
@@ -1836,3 +2262,12 @@ ListUsersResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+ListAvailabilityConfigurationsResponseTypeDef = TypedDict(
+    "ListAvailabilityConfigurationsResponseTypeDef",
+    {
+        "AvailabilityConfigurations": List[AvailabilityConfigurationTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
